diff libinterp/corefcn/strfns.cc @ 30896:c9788d7f6e65

maint: Use "fcn" as preferred abbreviation for "function" in libinterp/. * __eigs__.cc, bsxfun.cc, cellfun.cc, daspk.cc, dasrt.cc, dassl.cc, data.cc, debug.cc, error.cc, graphics.cc, graphics.in.h, gzfstream.h, ls-hdf5.cc, lsode.cc, max.cc, oct-opengl.h, quad.cc, strfns.cc, utils.cc, utils.h, variables.cc, __ode15__.cc, gzip.cc, cdef-manager.cc, ov-fcn-handle.cc, ov-java.cc, ov-usr-fcn.cc, bp-table.cc, bp-table.h, lex.h, lex.ll, oct-parse.yy, pt-eval.cc: Replace "func", "fun", "fn" in documentation and variable names with "fcn".
author Rik <rik@octave.org>
date Tue, 05 Apr 2022 08:33:58 -0700
parents 32d2b6604a9f
children e88a07dec498
line wrap: on
line diff
--- a/libinterp/corefcn/strfns.cc	Tue Apr 05 01:06:00 2022 -0400
+++ b/libinterp/corefcn/strfns.cc	Tue Apr 05 08:33:58 2022 -0700
@@ -319,7 +319,7 @@
 */
 
 static octave_value
-do_strcmp_fun (const octave_value& arg0, const octave_value& arg1,
+do_strcmp_fcn (const octave_value& arg0, const octave_value& arg1,
                octave_idx_type n, const char *fcn_name,
                bool (*array_op) (const Array<char>&, const Array<char>&,
                                  octave_idx_type),
@@ -526,7 +526,7 @@
 
 
 // These are required so that they match the same signature as strncmp
 // and strncmpi and can therefore be used in do_strcmp_fun.
 
 template <typename T, typename T_size_type>
 static bool
@@ -560,7 +560,7 @@
   if (args.length () != 2)
     print_usage ();
 
-  return ovl (do_strcmp_fun (args(0), args(1), 0, "strcmp",
+  return ovl (do_strcmp_fcn (args(0), args(1), 0, "strcmp",
                              strcmp_ignore_n, strcmp_ignore_n));
 }
 
@@ -651,7 +651,7 @@
   octave_idx_type n = args(2).idx_type_value ();
 
   if (n > 0)
-    return ovl (do_strcmp_fun (args(0), args(1), n, "strncmp",
+    return ovl (do_strcmp_fcn (args(0), args(1), n, "strncmp",
                                string::strncmp,
                                string::strncmp));
   else
@@ -698,7 +698,7 @@
   if (args.length () != 2)
     print_usage ();
 
-  return ovl (do_strcmp_fun (args(0), args(1), 0, "strcmpi",
+  return ovl (do_strcmp_fcn (args(0), args(1), 0, "strcmpi",
                              strcmpi_ignore_n, strcmpi_ignore_n));
 }
 
@@ -732,7 +732,7 @@
   octave_idx_type n = args(2).idx_type_value ();
 
   if (n > 0)
-    return ovl (do_strcmp_fun (args(0), args(1), n, "strncmpi",
+    return ovl (do_strcmp_fcn (args(0), args(1), n, "strncmpi",
                                string::strncmpi,
                                string::strncmpi));
   else
@@ -526,7 +526,7 @@
 
 // These are required so that they match the same signature as strncmp
-// and strncmpi and can therefore be used in do_strcmp_fun.
+// and strncmpi and can therefore be used in do_strcmp_fcn.
 
 template <typename T, typename T_size_type>